@@ -47,13 +47,14 @@ use overload
 __GNU_MP_VERSION __GNU_MP_VERSION_MINOR __GNU_MP_VERSION_PATCHLEVEL
 __GNU_MP_RELEASE __GMP_CC __GMP_CFLAGS
 Rmpq_abs Rmpq_add Rmpq_canonicalize Rmpq_clear Rmpq_cmp Rmpq_cmp_si Rmpq_cmp_ui
-Rmpq_create_noval Rmpq_denref Rmpq_div Rmpq_div_2exp Rmpq_equal 
+Rmpq_cmp_z
+Rmpq_create_noval Rmpq_denref Rmpq_div Rmpq_div_2exp Rmpq_equal
 Rmpq_fprintf
-Rmpq_get_d 
+Rmpq_get_d
 Rmpq_get_den Rmpq_get_num Rmpq_get_str Rmpq_init Rmpq_init_nobless Rmpq_inp_str
-Rmpq_inv Rmpq_mul Rmpq_mul_2exp Rmpq_neg Rmpq_numref Rmpq_out_str Rmpq_printf 
+Rmpq_inv Rmpq_mul Rmpq_mul_2exp Rmpq_neg Rmpq_numref Rmpq_out_str Rmpq_printf
 Rmpq_set Rmpq_set_d Rmpq_set_den Rmpq_set_f Rmpq_set_num Rmpq_set_si Rmpq_set_str
-Rmpq_set_ui Rmpq_set_z Rmpq_sgn 
+Rmpq_set_ui Rmpq_set_z Rmpq_sgn
 Rmpq_sprintf Rmpq_snprintf
 Rmpq_sub Rmpq_swap
 TRmpq_out_str TRmpq_inp_str
@@ -63,20 +64,21 @@ qgmp_randinit_set qgmp_randinit_default_nobless qgmp_randinit_mt_nobless
 qgmp_randinit_lc_2exp_nobless qgmp_randinit_lc_2exp_size_nobless qgmp_randinit_set_nobless
 qgmp_urandomb_ui qgmp_urandomm_ui
     );
-    our $VERSION = '0.37';
-    $VERSION = eval $VERSION;
+    our $VERSION = '0.38';
+    #$VERSION = eval $VERSION;
 
     DynaLoader::bootstrap Math::GMPq $VERSION;
 
     %Math::GMPq::EXPORT_TAGS =(mpq => [qw(
 Rmpq_abs Rmpq_add Rmpq_canonicalize Rmpq_clear Rmpq_cmp Rmpq_cmp_si Rmpq_cmp_ui
-Rmpq_create_noval Rmpq_denref Rmpq_div Rmpq_div_2exp Rmpq_equal 
+Rmpq_cmp_z
+Rmpq_create_noval Rmpq_denref Rmpq_div Rmpq_div_2exp Rmpq_equal
 Rmpq_fprintf
-Rmpq_get_d 
+Rmpq_get_d
 Rmpq_get_den Rmpq_get_num Rmpq_get_str Rmpq_init Rmpq_init_nobless Rmpq_inp_str
-Rmpq_inv Rmpq_mul Rmpq_mul_2exp Rmpq_neg Rmpq_numref Rmpq_out_str Rmpq_printf 
+Rmpq_inv Rmpq_mul Rmpq_mul_2exp Rmpq_neg Rmpq_numref Rmpq_out_str Rmpq_printf
 Rmpq_set Rmpq_set_d Rmpq_set_den Rmpq_set_f Rmpq_set_num Rmpq_set_si Rmpq_set_str
-Rmpq_set_ui Rmpq_set_z Rmpq_sgn 
+Rmpq_set_ui Rmpq_set_z Rmpq_sgn
 Rmpq_sprintf Rmpq_snprintf
 Rmpq_sub Rmpq_swap
 TRmpq_out_str TRmpq_inp_str
@@ -92,14 +94,14 @@ sub dl_load_flags {0} # Prevent DynaLoader from complaining and croaking
 sub new {
 
     # This function caters for 2 possibilities:
-    # 1) that 'new' has been called OOP style - in which 
+    # 1) that 'new' has been called OOP style - in which
     #    case there will be a maximum of 3 args
     # 2) that 'new' has been called as a function - in
     #    which case there will be a maximum of 2 args.
     # If there are no args, then we just want to return an
     # initialized Math::GMPq
     if(!@_) {return Rmpq_init()}
-   
+
     if(@_ > 3) {die "Too many arguments supplied to new()"}
 
     # If 'new' has been called OOP style, the first arg is the string
@@ -111,7 +113,7 @@ sub new {
     if(!ref($_[0]) && $_[0] eq "Math::GMPq") {
       shift;
       if(!@_) {return Rmpq_init()}
-      } 
+      }
 
     # @_ can now contain a maximum of 2 args - the value, and iff the value is
     # a string, (optionally) the base of the numeric string.
@@ -146,7 +148,7 @@ sub new {
       Rmpq_set_d($ret, $arg1);
       return $ret;
     }
-    
+
     if($type == _POK_T) {
       if(@_ > 1) {die "Too many arguments supplied to new() - expected no more than two"}
       $base = shift if @_;
@@ -212,7 +214,7 @@ sub _rewrite {
     shift(@split);
 
     my $start = 0;
-    
+
     for(@split) {
        push(@ret, substr($_[0], $start, $_ - $start));
        $start = $_;
@@ -292,7 +294,7 @@ __END__
 =head1 NAME
 
    Math::GMPq - perl interface to the GMP library's rational (mpq) functions.
-   
+
 =head1 DEPENDENCIES
 
    This module needs the GMP C library - available from:
@@ -309,8 +311,8 @@ __END__
 
    IMPORTANT:
     If your perl was built with '-Duse64bitint' you need to assign
-    all integers larger than 52-bit in a 'use integer;' block. 
-    Failure to do so can result in the creation of the variable as 
+    all integers larger than 52-bit in a 'use integer;' block.
+    Failure to do so can result in the creation of the variable as
     an NV (rather than an IV) - with a resultant loss of precision.
 
 =head1 SYNOPSIS
@@ -357,7 +359,7 @@ __END__
 =head1 MEMORY MANAGEMENT
 
    Objects created with Rmpq_create_init() have been
-   blessed into package Math::GMPq. They will 
+   blessed into package Math::GMPq. They will
    therefore be automatically cleaned up by the
    DESTROY() function whenever they go out of scope.
 
@@ -366,10 +368,10 @@ __END__
    It will then be up to you to clean up the memory
    associated with these objects by calling
    Rmpq_clear($op), for each object.
-   Alternatively the objects will be cleaned up 
+   Alternatively the objects will be cleaned up
    when the script ends.
    I don't know why you would want to create unblessed
-   objects - the point is you can if you want to :-) 
+   objects - the point is you can if you want to :-)
 
 =head1 FUNCTIONS
 
@@ -378,7 +380,7 @@ __END__
    These next 3 functions are demonstrated above:
    $rop   = Rmpq_init();
    $rop   = Rmpq_set_strl($str, $base); # 1 < $base < 63
-   $str = Rmpq_get_str($op, $base); # 1 < $base < 37 
+   $str = Rmpq_get_str($op, $base); # 1 < $base < 37
 
    The following functions are simply wrappers around a GMP
    function of the same name. eg. Rmpq_swap() is a wrapper around
@@ -389,7 +391,7 @@ __END__
    the return value of Rmpq_init or Rmpq_init_nobless
    functions. They are in fact references to GMP structures.
    The "$rop" argument(s) contain the result(s) of the calculation
-   being done, the "$op" argument(s) being the input(s) into that 
+   being done, the "$op" argument(s) being the input(s) into that
    calculation.
    Generally, $rop, $op1, $op2, etc. can be the same perl variable,
    though usually they will be distinct perl variables referencing
@@ -400,11 +402,11 @@ __END__
    as $r1 += $r1. Otoh, Rmpq_add($r1, $r2, $r3), where each of the
    arguments is a different reference to a different GMP structure
    would add $r2 to $r3 and store the result in $r1. Think of it as
-   $r1 = $r2 + $r3. Mostly, the first argument is the argument that 
+   $r1 = $r2 + $r3. Mostly, the first argument is the argument that
    stores the result and subsequent arguments provide the input values.
    Exceptions to this can be found in some of the functions that
-   actually return a value. 
-   Like I say, see the GMP manual for details. I hope it's 
+   actually return a value.
+   Like I say, see the GMP manual for details. I hope it's
    intuitively obvious or quickly becomes so. Also see the test
    suite that comes with the distro for some examples of usage.
 
@@ -419,10 +421,8 @@ __END__
    the only interest is whether it evaluates as true or false.
 
    "$str" simply means a string of symbols that represent a number,
-   eg "1234567890987654321234567/7" which might be a base 10 number,
-   or "zsa34760sdfgq123r5/11" which would have to represent at least
-   a base 36 number (because "z" is a valid digit only in bases 36
-   and above). Valid bases for GMP numbers are 2 to 62 (inclusive).
+   eg "1234567890987654321234567/7".
+   Valid bases for GMP numbers are 2 to 62 (inclusive).
 
    ############
 
@@ -438,7 +438,7 @@ __END__
 
    Normally, a variable should be initialized once only or at least be
    cleared, using `Rmpq_clear', between initializations.
-   'DESTROY' (which calls 'Rmpq_clear') is automatically called on 
+   'DESTROY' (which calls 'Rmpq_clear') is automatically called on
    blessed objects whenever they go out of scope.
 
    See the section 'MEMORY MANAGEMENT' (above).
@@ -466,7 +466,7 @@ __END__
     Set $rop from $str in the given base $base. The string can be
     an integer like "41" or a fraction like "41/152".  The fraction
     must be in canonical form, or if not then `Rmpq_canonicalize'
-    must be called. The numerator and optional denominator are 
+    must be called. The numerator and optional denominator are
     parsed the same as in `Rmpz_set_str'. $base can vary from 2 to
     62, or if $base is 0 then the leading characters are used: `0x'
     for hex, `0' for octal, or decimal otherwise.  Note that this
@@ -481,7 +481,7 @@ __END__
    COMBINED INITIALIZATION AND ASSIGNMENT
 
    NOTE: Do NOT use these functions if $rop has already
-   been initialised. Instead use the Rmpq_set* functions 
+   been initialised. Instead use the Rmpq_set* functions
    in 'Assignment Functions' (above)
 
    First read the section 'MEMORY MANAGEMENT' (above).
@@ -591,12 +591,17 @@ __END__
     are non-equal.  Although `Rmpq_cmp' can be used for the
     same purpose, this function is much faster.
 
+   $si = Rmpq_cmp_z($op, $z);# $z is Math::GMPz or Math::GMP object
+    Return a positive value if $op > $z.
+    Return zero if $op == $z.
+    Return a negative value if $op < $z.
+
    ################
 
    I/O of RATIONALS
 
    $bytes_written = Rmpq_out_str([$prefix,] $op, $base [, $suffix]);
-    BEST TO USE TRmpq_out_str INSTEAD. 
+    BEST TO USE TRmpq_out_str INSTEAD.
     Output $op to STDOUT, as a string of digits in base $base.
     The base may vary from 2 to 36. Output is in the form `num/den'
     or if the denominator is 1 then just `num'. Return the number
@@ -630,7 +635,7 @@ __END__
     for hexadecimal, `0' for octal, or decimal otherwise.  The leading
     characters are examined separately for the numerator and
     denominator of a fraction, so for instance `0x10/11' is 16/11,
-    whereas `0x10/0x11' is 16/17. 
+    whereas `0x10/0x11' is 16/17.
 
    $bytes_read = TRmpq_inp_str($rop, $stream, $base);
     As for Rmpq_inp_str, except that there's the capability to read
@@ -642,7 +647,7 @@ __END__
 
    #######################
 
-   RANDOM NUMBER FUNCTIONS 
+   RANDOM NUMBER FUNCTIONS
 
    $state = qgmp_randinit_default();
     This is the Math::GMPq interface to the gmp library function
@@ -670,10 +675,10 @@ __END__
     X = ($mpz*X + $ui) mod (2 ** $m2exp). The low bits of X in this
     algorithm are not very random. The least significant bit will have a
     period no more than 2, and the second bit no more than 4, etc. For
-    this reason only the high half of each X is actually used. 
+    this reason only the high half of each X is actually used.
     When a random number of more than m2exp/2 bits is to be generated,
     multiple iterations of the recurrence are used and the results
-    concatenated. 
+    concatenated.
 
    $state = qgmp_randinit_lc_2exp_size($ui);
     This is the Math::GMPq interface to the gmp library function
@@ -683,10 +688,10 @@ __END__
     Initialize state for a linear congruential algorithm as per
     gmp_randinit_lc_2exp. a, c and m2exp are selected from a table,
     chosen so that $ui bits (or more) of each X will be used,
-    ie. m2exp/2 >= $ui. 
+    ie. m2exp/2 >= $ui.
     If $ui is bigger than the table data provides then the function fails
     and dies with an appropriate error message. The maximum value for $ui
-    currently supported is 128. 
+    currently supported is 128.
 
    $state2 = qgmp_randinit_set($state1);
     This is the Math::GMPq interface to the gmp library function
@@ -709,39 +714,40 @@ __END__
     These are the Math::GMPz interfaces to the gmp library functions
     'gmp_randseed' and 'gmp_randseed_ui'.
     Seed an initialised (but not yet seeded) $state with $mpz/$ui.
-    Either Math::GMP or Math::GMPz is required for 'gmp_randseed'.   
+    Either Math::GMP or Math::GMPz is required for 'gmp_randseed'.
 
    $ui = qgmp_urandomb_ui($state, $bits);
     This is the Math::GMPq interface to the gmp library function
     'gmp_urandomb_ui'.
     Return a uniformly distributed random number of $bits bits, ie. in
     the range 0 to 2 ** ($bits - 1) inclusive. $bits must be less than or
-    equal to the number of bits in an unsigned long. 
+    equal to the number of bits in an unsigned long.
 
    $ui2 = qgmp_urandomm_ui($state, $ui1);
     This is the Math::GMPq interface to the gmp library function
     'gmp_urandomm_ui'.
     Return a uniformly distributed random number in the range 0 to
-    $ui1 - 1, inclusive.  
+    $ui1 - 1, inclusive.
 
    qgmp_randclear($state);
     Destroys $state, as also does Math::GMPq::Random::DESTROY - two
     identical functions.
     Use only if $state is an unblessed object - ie if it was initialised
-    using one of the qgmp_randinit*_nobless functions. 
+    using one of the qgmp_randinit*_nobless functions.
 
    ####################
 
-   OPERATOR OVERLOADING 
+   OPERATOR OVERLOADING
 
    Overloading occurs with numbers, strings,Math::GMPq objects and, to a
-   limited extent, Math::MPFR objects (iff version 3.13 or later of 
-   Math::MPFR has been installed).
+   limited extent, Math::GMP or Math::GMPz objects (iff the gmp library is
+   version 6.1.0 or later) and Math::MPFR objects (iff version 3.13 or
+   later of Math::MPFR has been installed).
    Strings are first converted to Math::GMPq objects, then canonicalized.
    See the Rmpq_set_str documentation (above) in the section "ASSIGNMENT
    FUNCTIONS" regarding permissible string formats.
    The following operators are overloaded:
-   
+
     + - * /
     += -= *= /= ++ --
     == != !
@@ -755,7 +761,9 @@ __END__
     and '**' operators, and will work only if Math::MPFR is at
     version 3.13 or later - in which case the operation will
     return a Math::MPFR object.
-
+    Math::GMP or Math::GMPz objects can be used only with the
+    comparison operators ( == != < <= > >= <=> ), and only if Math::GMPq
+    has been built against gmp-6.1.0 or later.
     In those situations where the overload subroutine operates on 2
     perl variables, then obviously one of those perl variables is
     a Math::GMPq object. To determine the value of the other variable
@@ -764,7 +772,7 @@ __END__
     to step 6:
 
     1. If the variable is an unsigned long then that value is used.
-       The variable is considered to be an unsigned long if 
+       The variable is considered to be an unsigned long if
        (perl 5.8 and later) the UOK flag is set or if (perl 5.6)
        SvIsUV() returns true.
 
@@ -779,19 +787,19 @@ __END__
 
     4. If the variable is a string (ie the POK flag is set) then the
        value of that string is used. Octal strings must begin with
-       '0', hex strings must begin with either '0x' or '0X' - 
-       otherwise the string is assumed to be decimal. If the POK 
+       '0', hex strings must begin with either '0x' or '0X' -
+       otherwise the string is assumed to be decimal. If the POK
        flag is set, but the string is not a valid base 8, 10, or 16
        number, the subroutine croaks with an appropriate error
        message. If the string is of the form 'numerator/denominator',
-       then the bases of the numerator and the denominator are 
+       then the bases of the numerator and the denominator are
        assessed individually. ie '0xa123/ff' is not a valid number
        (because 'ff' is not a valid base 10 number). That needs to
        be rewritten as '0xa123/0xff'.
 
     5. If the variable is a Math::GMPq object (or, for operators
-       specified above, a Math::MPFR object) then the value of that
-       object is used.
+       specified above, a Math::MPFR/Math::GMP/Math::GMPz object)
+       then the value of that object is used.
 
     6. If none of the above is true, then the second variable is
        deemed to be of an invalid type. The subroutine croaks with
@@ -803,7 +811,7 @@ __END__
 
    $GMP_version = Math::GMPq::gmp_v;
     Returns the version of the GMP library (eg 4.1.3) being used by
-    Math::GMPq. The function is not exportable. 
+    Math::GMPq. The function is not exportable.
 
    $GMP_cc = Math::GMPq::__GMP_CC;
    $GMP_cflags = Math::GMPq::__GMP_CFLAGS;
@@ -815,7 +823,7 @@ __END__
     Returns undef if Math::GMPq has been built against an earlier
     version of the gmp library.
     (These functions are in @EXPORT_OK and are therefore exportable
-    by request. They are not listed under the ":mpq" tag.)  
+    by request. They are not listed under the ":mpq" tag.)
 
    $major = Math::GMPq::__GNU_MP_VERSION;
    $minor = Math::GMPq::__GNU_MP_VERSION_MINOR;
@@ -824,7 +832,7 @@ __END__
     for the GMP library version used to build Math::GMPq. Values are
     as specified in the gmp.h that was used to build Math::GMPq.
     (These functions are in @EXPORT_OK and are therefore exportable
-    by request. They are not listed under the ":mpq" tag.) 
+    by request. They are not listed under the ":mpq" tag.)
 
    ################
 
@@ -882,7 +890,7 @@ __END__
 
    $si = Rmpq_snprintf($buffer, $bytes, $format_string, $var, $buflen);
 
-    Form a null-terminated string in $buffer. No more than $bytes 
+    Form a null-terminated string in $buffer. No more than $bytes
     bytes will be written. To get the full output, $bytes must be
     enough for the string and null-terminator. $buffer must be large
     enough to accommodate the string and null-terminator, and is
@@ -907,18 +915,18 @@ __END__
 
     You can get segfaults if you pass the wrong type of
     argument to the functions - so if you get a segfault, the
-    first thing to do is to check that the argument types 
+    first thing to do is to check that the argument types
     you have supplied are appropriate.
 
 =head1 LICENSE
 
-    This program is free software; you may redistribute it and/or 
+    This program is free software; you may redistribute it and/or
     modify it under the same terms as Perl itself.
-    Copyright 2006-2011, 2013 Sisyphus
+    Copyright 2006-2011, 2013-14, Sisyphus
 
 =head1 AUTHOR
 
     Sisyphus <sisyphus at(@) cpan dot (.) org>
 
 
-=cut
\ No newline at end of file
+=cut
